@@ -16,6 +16,7 @@
 #include "umldoc.h"
 #include "stereotype.h"
 #include "umlwidget.h"
+#include "dontaskagain.h"
 
 // kde includes
 #include <KMessageBox>
@@ -28,6 +29,10 @@
 #include <QLabel>
 #include <QLineEdit>
 
+DefineDontAskAgainItem(allItem, QLatin1String("all"), i18n("Enable all messages"));
+DefineDontAskAgainItem(askDeleteAssociationItem, QLatin1String("delete-association"), i18n("Enable 'delete association' related messages"));
+DefineDontAskAgainItem(askDeleteDiagramItem, QLatin1String("delete-diagram"), i18n("Enable 'delete diagram' related messages"));
+
 namespace Dialog_Utils {
 
 /**
@@ -96,6 +101,43 @@ bool askName(const QString& title, const QString& prompt, QString& name)
      return ok;
 }
 
+/**
+ * Ask the user for permission to delete an association.
+ *
+ * @return true - user want to continue
+ * @return false - user want to cancel
+ */
+bool askDeleteAssociation()
+{
+    return KMessageBox::warningContinueCancel(
+        UMLApp::app(),
+        i18n("You are about to delete an association. Do you really want to continue?"),
+        i18n("Delete Association"),
+        KStandardGuiItem::cont(),
+        KStandardGuiItem::cancel(),
+        askDeleteAssociationItem.name()) == KMessageBox::Continue;
+}
+
+/**
+ * Ask the user for permission to delete a diagram.
+ *
+ * @return true - user want to continue
+ * @return false - user want to cancel
+ */
+bool askDeleteDiagram(const QString &name)
+{
+    QString text = name.isEmpty() ? i18n("You are about to delete the entire diagram.\nAre you sure?")
+                                  : i18n("Are you sure you want to delete diagram %1?", name);
+
+    return KMessageBox::warningContinueCancel(
+        UMLApp::app(),
+        text,
+        i18n("Delete Diagram?"),
+        KGuiItem(i18n("&Delete")),
+        KStandardGuiItem::cancel(),
+        askDeleteDiagramItem.name()) == KMessageBox::Continue;
+}
+
 /**
  * Helper function for inserting available stereotypes into a KComboBox
  *
