@@ -77,7 +77,7 @@ public:
     virtual void setMessageText(FloatingTextWidget *ft);
     virtual void setText(FloatingTextWidget *ft, const QString &newText);
 
-    virtual void showPropertiesDialog();
+    virtual bool showPropertiesDialog();
 
     virtual QString lwOperationText();
     virtual UMLClassifier *lwClassifier();
@@ -181,17 +181,16 @@ public:
 
     void clipSize();
 
-    bool loadFromXMI(QDomElement& qElement, const UMLWidgetList& widgets,
+    bool loadFromXMI1(QDomElement& qElement, const UMLWidgetList& widgets,
                      const MessageWidgetList* messages);
-    virtual bool loadFromXMI(QDomElement& qElement);
-    virtual void saveToXMI(QDomDocument &qDoc, QDomElement &qElement);
+    virtual bool loadFromXMI1(QDomElement& qElement);
+    virtual void saveToXMI1(QDomDocument &qDoc, QDomElement &qElement);
 
     void cleanup();
 
     bool isPointAddable();
     bool isPointRemovable();
 
-    //:TODO: the following four methods should be protected
     virtual void mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event);
     virtual void mouseMoveEvent(QGraphicsSceneMouseEvent *event);
     virtual void mousePressEvent(QGraphicsSceneMouseEvent *event);
